@@ -15,10 +15,7 @@
 #include <QSortFilterProxyModel>
 #include <qmimetype.h>
 
-namespace Ui
-{
-class AppChooserDialog;
-}
+#include <KService>
 
 class ApplicationItem
 {
@@ -28,11 +25,14 @@ public:
         AllApplications,
     };
 
-    explicit ApplicationItem(const QString &name, const QString &icon, const QString &desktopFileName);
+    explicit ApplicationItem(const QString &name, const KService::Ptr &service);
 
     QString applicationName() const;
+    QString applicationGenericName() const;
+    QString applicationUntranslatedGenericName() const;
     QString applicationIcon() const;
     QString applicationDesktopFile() const;
+    QList<QMimeType> supportedMimeTypes() const;
 
     void setApplicationCategory(ApplicationCategory category);
     ApplicationCategory applicationCategory() const;
@@ -41,27 +41,29 @@ public:
 
 private:
     QString m_applicationName;
-    QString m_applicationIcon;
-    QString m_applicationDesktopFile;
+    KService::Ptr m_applicationService;
+    QList<QMimeType> m_supportedMimeTypes;
     ApplicationCategory m_applicationCategory;
 };
 
 class AppFilterModel : public QSortFilterProxyModel
 {
     Q_OBJECT
-    Q_PROPERTY(bool showOnlyPreferredApps READ showOnlyPreferredApps WRITE setShowOnlyPrefferedApps NOTIFY showOnlyPreferredAppsChanged)
+    Q_PROPERTY(bool showOnlyPreferredApps READ showOnlyPreferredApps WRITE setShowOnlyPreferredApps NOTIFY showOnlyPreferredAppsChanged)
     Q_PROPERTY(QString filter READ filter WRITE setFilter NOTIFY filterChanged)
 
 public:
     explicit AppFilterModel(QObject *parent = nullptr);
-    ~AppFilterModel() override;
 
-    void setShowOnlyPrefferedApps(bool show);
+    void setShowOnlyPreferredApps(bool show);
     bool showOnlyPreferredApps() const;
 
     void setDefaultApp(const QString &);
     QString defaultApp() const;
 
+    void setLastUsedApp(const QString &);
+    QString lastUsedApp() const;
+
     void setFilter(const QString &text);
     QString filter() const;
 
@@ -77,6 +79,7 @@ private:
     bool m_showOnlyPreferredApps = true;
     QString m_filter;
     QString m_defaultApp;
+    QString m_lastUsedApp;
 };
 
 class AppChooserData : public QObject
@@ -84,11 +87,12 @@ class AppChooserData : public QObject
     Q_OBJECT
     Q_PROPERTY(QString fileName READ fileName WRITE setFileName NOTIFY fileNameChanged)
     Q_PROPERTY(QString defaultApp READ defaultApp WRITE setDefaultApp NOTIFY defaultAppChanged)
+    Q_PROPERTY(QString lastUsedApp READ lastUsedApp WRITE setLastUsedApp NOTIFY lastUsedAppChanged)
     Q_PROPERTY(QString mimeName READ mimeName WRITE setMimeName NOTIFY mimeNameChanged)
     Q_PROPERTY(QString mimeDesc READ mimeDesc NOTIFY mimeDescChanged)
 
 public:
-    AppChooserData(QObject *parent = nullptr);
+    explicit AppChooserData(QObject *parent = nullptr);
 
     QString fileName() const;
     void setFileName(const QString &fileName);
@@ -98,6 +102,10 @@ public:
     void setDefaultApp(const QString &defaultApp);
     Q_SIGNAL void defaultAppChanged();
 
+    QString lastUsedApp() const;
+    void setLastUsedApp(const QString &lastUsedApp);
+    Q_SIGNAL void lastUsedAppChanged();
+
     QString mimeName() const;
     void setMimeName(const QString &mimeName);
     Q_SIGNAL void mimeNameChanged();
@@ -111,6 +119,7 @@ public:
 
 private:
     QString m_defaultApp;
+    QString m_lastUsedApp;
     QString m_fileName;
     QString m_mimeName;
 };
@@ -122,13 +131,15 @@ class AppModel : public QAbstractListModel
 public:
     enum ItemRoles {
         ApplicationNameRole = Qt::UserRole + 1,
+        ApplicationGenericNameRole,
+        ApplicationUntranslatedGenericNameRole,
         ApplicationIconRole,
         ApplicationDesktopFileRole,
         ApplicationCategoryRole,
+        ApplicationSupportedMimeTypesRole,
     };
 
     explicit AppModel(QObject *parent = nullptr);
-    ~AppModel() override;
 
     void setPreferredApps(const QStringList &list);
 
@@ -152,7 +163,7 @@ class AppChooserDialog : public QuickDialog
     Q_OBJECT
 public:
     explicit AppChooserDialog(const QStringList &choices,
-                              const QString &defaultApp,
+                              const QString &lastUsedApp,
                               const QString &fileName,
                               const QString &mimeName = QString(),
                               QObject *parent = nullptr);
