@@ -32,76 +32,6 @@ class QWindow;
 
 namespace WaylandIntegration
 {
-class WaylandOutput
-{
-    Q_GADGET
-public:
-    enum OutputType {
-        Laptop,
-        Monitor,
-        Television,
-        Workspace,
-        Virtual,
-    };
-    Q_ENUM(OutputType)
-    QString manufacturer() const
-    {
-        return m_output->manufacturer();
-    }
-    QString model() const
-    {
-        return m_output->model();
-    }
-    QPoint globalPosition() const
-    {
-        return m_output->globalPosition();
-    }
-    QSize resolution() const
-    {
-        return m_output->pixelSize();
-    }
-    OutputType outputType() const
-    {
-        return m_outputType;
-    }
-
-    QSharedPointer<KWayland::Client::Output> output() const
-    {
-        return m_output;
-    }
-    void setOutput(const QSharedPointer<KWayland::Client::Output> &output)
-    {
-        m_output = output;
-        setOutputType(output->model());
-    }
-
-    void setWaylandOutputName(int outputName)
-    {
-        m_waylandOutputName = outputName;
-    }
-    int waylandOutputName() const
-    {
-        return m_waylandOutputName;
-    }
-
-    void setWaylandOutputVersion(int outputVersion)
-    {
-        m_waylandOutputVersion = outputVersion;
-    }
-    int waylandOutputVersion() const
-    {
-        return m_waylandOutputVersion;
-    }
-
-private:
-    void setOutputType(const QString &model);
-    OutputType m_outputType = Monitor;
-    QSharedPointer<KWayland::Client::Output> m_output;
-
-    // Needed for later output binding
-    int m_waylandOutputName;
-    int m_waylandOutputVersion;
-};
 
 struct Stream {
     ScreencastingStream *stream = nullptr;
@@ -114,7 +44,7 @@ struct Stream {
 
     void close();
 };
-typedef QVector<Stream> Streams;
+typedef QList<Stream> Streams;
 
 class WaylandIntegration : public QObject
 {
@@ -128,11 +58,11 @@ bool isStreamingEnabled();
 bool isStreamingAvailable();
 
 void acquireStreamingInput(bool acquire);
-Stream startStreamingOutput(quint32 outputName, Screencasting::CursorMode mode);
 Stream startStreamingOutput(QScreen *screen, Screencasting::CursorMode mode);
 Stream startStreamingWorkspace(Screencasting::CursorMode mode);
 Stream startStreamingVirtual(const QString &name, const QSize &size, Screencasting::CursorMode mode);
 Stream startStreamingWindow(const QMap<int, QVariant> &win, Screencasting::CursorMode mode);
+Stream startStreamingRegion(const QRect &region, Screencasting::CursorMode mode);
 void stopStreaming(uint node);
 
 void requestPointerButtonPress(quint32 linuxButton);
@@ -149,8 +79,6 @@ void requestTouchDown(quint32 touchPoint, const QPointF &pos);
 void requestTouchMotion(quint32 touchPoint, const QPointF &pos);
 void requestTouchUp(quint32 touchPoint);
 
-QMap<quint32, WaylandOutput> screens();
-
 void setParentWindow(QWindow *window, const QString &parentWindow);
 
 void init();
